@@ -38,8 +38,6 @@ def get_args(arguments=None):
             attributes
 
     """
-    arg_log = logging.getLogger()
-
     parser = argparse.ArgumentParser(
         description="Goodman CCD Reduction - CCD reductions for Goodman "
                     "spectroscopic data."
@@ -110,6 +108,11 @@ def get_args(arguments=None):
                         dest='ignore_flats',
                         help="Ignore flat field correction")
 
+    parser.add_argument('--skip-slit-trim',
+                        action='store_true',
+                        dest='skip_slit_trim',
+                        help="Do not apply slit trimming")
+
     parser.add_argument('--keep-cosmic-files',
                         action='store_true',
                         dest='keep_cosmic_files',
@@ -388,6 +391,6 @@ class MainApp(object):
         return True
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     main_app = MainApp()
     main_app()
